"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("./errors");
exports.selectPeers = (peers, nodeInfo, numOfPeers = 0) => {
    const nodeHeight = nodeInfo ? nodeInfo.height : 0;
    const filteredPeers = peers.filter((peer) => peer.height >= nodeHeight);
    if (filteredPeers.length === 0) {
        return [];
    }
    const sortedPeers = filteredPeers.sort((a, b) => b.height - a.height);
    const aggregation = 2;
    const calculatedHistogramValues = sortedPeers.reduce((histogramValues, peer) => {
        const val = Math.floor(peer.height / aggregation) * aggregation;
        histogramValues.histogram[val] =
            (histogramValues.histogram[val] ? histogramValues.histogram[val] : 0) +
                1;
        if (histogramValues.histogram[val] > histogramValues.max) {
            histogramValues.max = histogramValues.histogram[val];
            histogramValues.height = val;
        }
        return histogramValues;
    }, { height: 0, histogram: {}, max: -1 });
    const processedPeers = sortedPeers.filter(peer => peer &&
        Math.abs(calculatedHistogramValues.height - peer.height) <
            aggregation + 1);
    if (numOfPeers <= 0) {
        return processedPeers;
    }
    if (numOfPeers > processedPeers.length) {
        throw new errors_1.NotEnoughPeersError(`Requested number of peers: '${numOfPeers}' is more than the available number of good peers: '${processedPeers.length}'`);
    }
    if (numOfPeers === processedPeers.length) {
        return processedPeers;
    }
    if (numOfPeers === 1) {
        const goodPeer = [
            processedPeers[Math.floor(Math.random() * processedPeers.length)],
        ];
        return goodPeer;
    }
    const { peerList } = new Array(numOfPeers).fill(0).reduce(peerListObject => {
        const index = Math.floor(Math.random() * peerListObject.processedPeersArray.length);
        const peer = peerListObject.processedPeersArray[index];
        const tempProcessedPeers = peerListObject.processedPeersArray.filter((findPeer) => findPeer !== peer);
        return {
            peerList: [...peerListObject.peerList, peer],
            processedPeersArray: tempProcessedPeers,
        };
    }, { peerList: [], processedPeersArray: processedPeers });
    return peerList;
};
exports.selectForConnection = (peerInfoList, _nodeInfo) => peerInfoList;
//# sourceMappingURL=peer_selection.js.map